@@ -21,4 +21,4 @@ which gnome-autogen.sh || {
 ACLOCAL_FLAGS="$ACLOCAL_FLAGS -I m4"
 REQUIRED_AUTOMAKE_VERSION=1.8
 
-. gnome-autogen.sh
+. gnome-autogen.sh "$@"
