@@ -4,19 +4,18 @@
  *
  * Copyright (c) 2008-2010 Peng Huang <shawn.p.huang@gmail.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ *  This program is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "PYFallbackEditor.h"
 #include "PYHalfFullConverter.h"
@@ -76,13 +75,21 @@ FallbackEditor::processPunctForSimplifiedChinese (guint keyval, guint keycode, g
         m_double_quote = !m_double_quote;
         return TRUE;
     case ',':
-        commit ("，"); return TRUE;
-    case '.':
-        if (m_prev_committed_char >= '0' && m_prev_committed_char <= '9')
+        if (m_prev_committed_char >= '0' && m_prev_committed_char <= '9') {
+            m_prev_committed_char = keyval;
             return FALSE;
-        else
+        } else {
+            commit ("，");
+            return TRUE;
+        }
+    case '.':
+        if (m_prev_committed_char >= '0' && m_prev_committed_char <= '9') {
+            m_prev_committed_char = keyval;
+            return FALSE;
+        } else {
             commit ("。");
-        return TRUE;
+            return TRUE;
+        }
     case '<':
         commit ("《"); return TRUE;
     case '>':
@@ -144,13 +151,21 @@ FallbackEditor::processPunctForTraditionalChinese (guint keyval, guint keycode,
         m_double_quote = !m_double_quote;
         return TRUE;
     case ',':
-        commit ("，"); return TRUE;
-    case '.':
-        if (m_prev_committed_char >= '0' && m_prev_committed_char <= '9')
+        if (m_prev_committed_char >= '0' && m_prev_committed_char <= '9') {
+            m_prev_committed_char = keyval;
             return FALSE;
-        else
+        } else {
+            commit ("，");
+            return TRUE;
+        }
+    case '.':
+        if (m_prev_committed_char >= '0' && m_prev_committed_char <= '9') {
+            m_prev_committed_char = keyval;
+            return FALSE;
+        } else {
             commit ("。");
-        return TRUE;
+            return TRUE;
+        }
     case '<':
         commit ("《"); return TRUE;
     case '>':
@@ -201,6 +216,9 @@ FallbackEditor::processPunct (guint keyval, guint keycode, guint modifiers)
 gboolean
 FallbackEditor::processKeyEvent (guint keyval, guint keycode, guint modifiers)
 {
+    if (modifiers & IBUS_MOD4_MASK)
+        return FALSE;
+
     gboolean retval = FALSE;
 
     modifiers &= (IBUS_CONTROL_MASK |
@@ -218,8 +236,10 @@ FallbackEditor::processKeyEvent (guint keyval, guint keycode, guint modifiers)
         case IBUS_a ... IBUS_z:
         case IBUS_A ... IBUS_Z:
             if (modifiers == 0) {
-                if (!m_props.modeFull ())
+                if (!m_props.modeFull ()) {
+                    m_prev_committed_char = keyval;
                     return FALSE;
+                }
 
                 commit (HalfFullConverter::toFull (keyval));
                 retval = TRUE;
@@ -260,8 +280,10 @@ FallbackEditor::processKeyEvent (guint keyval, guint keycode, guint modifiers)
             keyval = IBUS_space;
         case IBUS_space:
             if (modifiers == 0) {
-                if (!m_props.modeFull ())
+                if (!m_props.modeFull ()) {
+                    m_prev_committed_char = keyval;
                     return FALSE;
+                }
 
                 commit ("　");
                 retval = TRUE;
@@ -271,6 +293,9 @@ FallbackEditor::processKeyEvent (guint keyval, guint keycode, guint modifiers)
         default:
             break;
     }
+
+    if (!retval)
+        m_prev_committed_char = keyval;
     return retval;
 }
 
