@@ -495,6 +495,15 @@ CloudCandidates::selectCandidate (EnhancedCandidate & enhanced)
     return SELECT_CANDIDATE_ALREADY_HANDLED;
 }
 
+void
+releaseUserData (gpointer user_data)
+{
+    CloudAsyncRequestUserData *data = static_cast<CloudAsyncRequestUserData *> (user_data);
+    if (data->event_id != 0) {
+        g_free (user_data);
+    }
+}
+
 void
 CloudCandidates::delayedCloudAsyncRequest (const gchar* pinyin)
 {
@@ -514,9 +523,11 @@ CloudCandidates::delayedCloudAsyncRequest (const gchar* pinyin)
     data->cloud_candidates = this;
 
     /* record the latest timer */
-    m_source_event_id = g_timeout_add (m_editor->m_config.cloudRequestDelayTime (),
-                                       delayedCloudAsyncRequestCallBack,
-                                       user_data);
+    m_source_event_id = g_timeout_add_full (G_PRIORITY_DEFAULT,
+                                            m_editor->m_config.cloudRequestDelayTime (),
+                                            delayedCloudAsyncRequestCallBack,
+                                            user_data,
+                                            releaseUserData);
     data->event_id = m_source_event_id;
     data->message = NULL;
     data->cancel_message = NULL;
@@ -537,6 +548,7 @@ CloudCandidates::delayedCloudAsyncRequestCallBack (gpointer user_data)
 
     /* only send with a latest timer */
     if (data->event_id == cloud_candidates->m_source_event_id) {
+        data->event_id = 0;
         cloud_candidates->m_source_event_id = 0;
         cloud_candidates->cloudAsyncRequest (user_data);
     }
@@ -564,7 +576,7 @@ CloudCandidates::cloudAsyncRequest (gpointer user_data)
     m_cancel_message = g_cancellable_new ();
     data->cancel_message = m_cancel_message;
 
-    SoupMessage *m_message = soup_message_new ("GET", query_request);
+    m_message = soup_message_new ("GET", query_request);
     soup_session_send_async (m_session, m_message, SOUP_MESSAGE_PRIORITY_NORMAL, m_cancel_message, cloudResponseCallBack, user_data);
     data->message = m_message;
 
@@ -576,23 +588,34 @@ CloudCandidates::cloudAsyncRequest (gpointer user_data)
 void
 CloudCandidates::cloudResponseCallBack (GObject *source_object, GAsyncResult *result, gpointer user_data)
 {
-    GInputStream *stream = soup_session_send_finish (SOUP_SESSION (source_object), result, NULL);
+    GError *error = NULL;
+    GInputStream *stream = soup_session_send_finish (SOUP_SESSION (source_object), result, &error);
     CloudAsyncRequestUserData *data = static_cast<CloudAsyncRequestUserData *> (user_data);
 
     CloudCandidates *cloud_candidates = data->cloud_candidates;
 
-    /* process results */
-    cloud_candidates->processCloudResponse (stream, cloud_candidates->m_editor->m_candidates, data->requested_pinyin);
+    if (!g_error_matches(error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
+        /* process results */
+        cloud_candidates->processCloudResponse (stream, cloud_candidates->m_editor->m_candidates, data->requested_pinyin);
 
-    cloud_candidates->updateLookupTable ();
+        cloud_candidates->updateLookupTable ();
+
+        /* reset m_message pointer only when it is not replaced with a new m_message */
+        cloud_candidates->m_message = NULL;
+        cloud_candidates->m_cancel_message = NULL;
+    }
+
+    if (error) {
+        g_error_free (error);
+    } else {
+        g_object_unref (stream);
+    }
 
     /* clean up message */
     g_object_unref (data->message);
-    cloud_candidates->m_message = NULL;
 
     /* clean up cancellable */
     g_object_unref (data->cancel_message);
-    cloud_candidates->m_cancel_message = NULL;
 
     g_free (user_data);
 }
