@@ -73,6 +73,8 @@ DoublePinyinEditor::insert (gint ch)
 #endif
 
     m_text.insert (m_cursor++, ch);
+    m_lookup_cursor = 0;
+
     updatePinyin ();
     update ();
 
@@ -88,6 +90,9 @@ gboolean
 DoublePinyinEditor::processKeyEvent (guint keyval, guint keycode,
                                               guint modifiers)
 {
+    if (modifiers & IBUS_MOD4_MASK)
+        return FALSE;
+
     /* handle ';' key */
     if (G_UNLIKELY (keyval == IBUS_semicolon)) {
         if (cmshm_filter (modifiers) == 0) {
