@@ -42,7 +42,8 @@ enum CandidateType {
     CANDIDATE_LUA_CONVERTER,
     CANDIDATE_CLOUD_INPUT,
     CANDIDATE_EMOJI,
-    CANDIDATE_ENGLISH
+    CANDIDATE_ENGLISH,
+    CANDIDATE_PREDICTED_PUNCTUATION
 };
 
 enum SelectCandidateAction {
