@@ -109,6 +109,12 @@ PinyinEditor::processPunct (guint keyval, guint keycode,
             return TRUE;
         }
         break;
+    case IBUS_bracketleft:
+        if (m_config.squareBracketPage ()) {
+            pageUp ();
+            return TRUE;
+        }
+        break;
     case IBUS_period:
         if (m_config.commaPeriodPage ()) {
             pageDown ();
@@ -121,6 +127,12 @@ PinyinEditor::processPunct (guint keyval, guint keycode,
             return TRUE;
         }
         break;
+    case IBUS_bracketright:
+        if (m_config.squareBracketPage ()) {
+            pageDown ();
+            return TRUE;
+        }
+        break;
     }
 
     if (m_config.autoCommit ()) {
